# Modeling Guidelines (Meta Model v3)
### On this page
  * [Full Modeling Example - LeanIX as an Application](https://help.sap.com/docs/leanix/ea/modeling-guidelines-v3#full-modeling-example---leanix-as-an-application)
  * [Tags vs. Custom Attributes](https://help.sap.com/docs/leanix/ea/modeling-guidelines-v3#tags-vs.-custom-attributes)
  * [Relations: Parent / Child vs. Requires / Required by vs. Explicit Relations](https://help.sap.com/docs/leanix/ea/modeling-guidelines-v3#relations:-parent-/-child-vs.-requires-/-required-by-vs.-explicit-relations)


In this section, we provide an overview of certain modeling guidelines within LeanIX. Our goal is to give you a clear idea of how to make use of LeanIX's structure and features in order to unlock its full potential.
**Note**
This page is a modeling guideline for Meta Model v3. For updated guidelines for Meta Model v4 see [Meta Model v4](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts.").
This page provides guidance on typical modeling questions within the LeanIX data model.
